from bdaserviceutils import get_cmd_arg

# def get_output_dataset_path():
#     return get_cmd_arg("output-dataset")
    
# def get_input_dataset_path():
#     return get_cmd_arg("input-dataset")

def get_path(name):
    return get_cmd_arg(name)
